@@ -321,6 +321,72 @@ FALCON_FUNC  falcon_systemCall ( ::Falcon::VMachine *vm )
       memFree( argv );
 }
 
+
+/*#
+   @function pread
+   @brief Executes an external process and waits for its termination.
+   @param command The command to be executed.
+   @param background If given and true, the process runs hidden.
+   @return The full output generated by the rpcess.
+   @raise ProcessError if the process couldn't be created.
+
+   This function launches an external system command and waits until the command
+   execution is terminated, returning the exit code of the child process. All the 
+   
+   for example:
+
+   @code
+   dir_contents = pread( "ls" )
+   > dir_contents
+   @endcode
+
+   If the process cannot be started if it fails to start, an error is raised.
+   
+   \note This function uses the standard system shell to execute the passed
+   commands, so it is possible to pipe applications and redirect streams
+   via the standard "|" and ">" command line characters.
+*/
+FALCON_FUNC  falcon_pread ( ::Falcon::VMachine *vm )
+{
+   Item *sys_req = vm->param(0);
+   Item *mode = vm->param(1);
+
+   if( sys_req == 0 || ( sys_req->type() != FLC_ITEM_STRING &&  sys_req->type() != FLC_ITEM_ARRAY ) )
+   {
+      vm->raiseModError( new ParamError( ErrorParam( e_inv_params, __LINE__ ) ) );
+      return;
+   }
+
+   bool background = mode == 0 ? false : mode->isTrue();
+   String *argv[4];
+
+   String shellName( ::Falcon::Sys::shellName() );
+   String shellParam( ::Falcon::Sys::shellParam() );
+   argv[0] = &shellName;
+   argv[1] = &shellParam;
+   argv[2] = sys_req->asString();
+   argv[3] = 0;
+
+   int retval=0;
+   GarbageString* gs = new GarbageString( vm );
+   if( ::Falcon::Sys::spawn_read( argv, false, background, &retval, gs ) )
+   {
+      if ( retval == 0x7F00 )
+      {
+         vm->raiseModError( new ProcessError( ErrorParam( FALPROC_ERR_CREATPROC, __LINE__ )
+            .desc( FAL_STR( proc_msg_prccreate ) )
+            .sysError( 0 ) ) );
+      }
+      else
+         vm->retval( gs );
+   }
+   else {
+      vm->raiseModError( new ProcessError( ErrorParam( FALPROC_ERR_CREATPROC, __LINE__ )
+         .desc( FAL_STR( proc_msg_prccreate ) )
+         .sysError( retval ) ) );
+   }
+}
+
 /*#
    @function exec
    @brief Launches a process in place of the host process.
